#include <qdir.h>

#include <kdebug.h>
#include <ksimpleconfig.h>

#include "kjsembed/jshookloader.h"
#include "global.h"

#include "doctype.h"
#include "doctype.moc"

DocType::DocType( const DocTypeInfo &i, QObject *parent, const char *name )
    : QObject( parent, name ), KXMLGUIClient(),
      typeInfo( i ), conf(0), hooks( 0 )
{
}

DocType::~DocType()
{

}

QString DocType::dataDir() const
{
    QString dir( "doctypes/%1" );
    return dir.arg( typeInfo.id() );
}

KConfig *DocType::config() const
{
    if ( !conf ) {
	///// XXX Hacked - should use KStdDirs
	QString configFile( "%1/%2rc" );
	QString configDir( "%1/%2" );
	QString cwd = QDir::currentDirPath();
	configFile = configFile.arg( configDir.arg(cwd).arg(dataDir()) ).arg( typeInfo.id() );

	kdDebug() << "Doctype: Created config file '" << configFile << "'" << endl;
	conf = new KSimpleConfig( configFile );
    }
    return conf;
}

KJSEmbed::JSHookLoader *DocType::jsHooks() const
{
    if ( !hooks ) {
	kdDebug() << "DocType: Creating jshook loader for '" << typeInfo.id() << "'" << endl;
	hooks = new KJSEmbed::JSHookLoader( Global::jscript(), config() );
    }
    return hooks;
}

void DocType::runJSHook( const QString &name )
{
    kdDebug() << "DocType: Running jshook '" << name << "'" << endl;
    jsHooks()->runHook( name );
}

void DocType::validate()
{
    kdDebug() << "DocType: Running validator" << endl;
}

void DocType::onLoad()
{
    kdDebug() << "DocType: Calling onLoad handler" << endl;
    runJSHook( "OnLoad" );
}

void DocType::onUnload()
{
    kdDebug() << "DocType: Calling onUnload handler" << endl;
    runJSHook( "OnUnload" );
}

// Local Variables:
// c-basic-offset: 4
// End:

