// -*- c++ -*-

#ifndef DOCTYPE_H
#define DOCTYPE_H

#include <qobject.h>
#include <kxmlguiclient.h>

#include "doctypeinfo.h"

class QStyleSheet;
class KConfig;
class DocTypeViewManager;

namespace KJSEmbed {
    class JSHookLoader;
};

/**
 * An abstract base class for DocTypes.
 *
 * @author Richard Moore, rich@kde.org
 * @version $Id: doctype.h,v 1.2 2001/12/16 00:12:56 rich Exp $
 */
class DocType : public QObject, public KXMLGUIClient
{
    Q_OBJECT

public:
    /** Creates a DocType with the specified meta-info. */
    DocType( const DocTypeInfo &info, QObject *parent=0, const char *name=0 );
    virtual ~DocType();

    //
    // Information
    //

    /** Returns the DocTypeInfo describing this DocType. */
    const DocTypeInfo &info() { return typeInfo; }

    /** Returns the data directory for this doctype. */
    QString dataDir() const;

    //
    // Factory methods
    //

    /** Get the config object for this DocType. */
    KConfig *config() const;

    /** 
     * A factory method for creating a DocTypeViewManager for this DocType.
     * This method should never return 0.
     */
    virtual DocTypeViewManager *createViewManager()=0;

    /**
     * A factory method for creating a QStyleSheet for this DocType. This
     * method returns 0 if no stylesheet exists.
     */
    virtual QStyleSheet *styleSheet() { return 0; }

    //
    // JS Hooks
    //
    KJSEmbed::JSHookLoader *jsHooks() const;

public slots:
    void runJSHook( const QString &name );
    virtual void validate();

    //
    // Event Handlers
    //
    virtual void onLoad();
    virtual void onUnload();

private:
    DocTypeInfo typeInfo;
    mutable KConfig *conf;
    mutable KJSEmbed::JSHookLoader *hooks;
};

#endif // DOCTYPE_H

// Local Variables:
// c-basic-offset: 4
// End:

