#include <qmultilineedit.h>
#include <qstylesheet.h>
#include <qtabwidget.h>

#include <kaction.h>
#include <kdebug.h>
#include <khtml_part.h>
#include <klibloader.h>
#include <klocale.h>

#include <rjmutils/richtexteditpart.h>
#include <rjmutils/srctexteditpart.h>

#include "docbookdoctype.h"

DocBookDocType::DocBookDocType( const DocTypeInfo &info )
    : DocType( info )
{
    createActions( actionCollection() );
    setXMLFile( "doctypes/docbook/docbookui.rc" );
}

QStyleSheet *DocBookDocType::styleSheet()
{
    return QStyleSheet::defaultSheet();
}

DocTypeViewManager *DocBookDocType::createViewManager()
{
    return new DocBookViewManager( this );
}

void DocBookDocType::createActions( KActionCollection *parent )
{
    KAction *test = new KAction( i18n("DocBook Action..."), 0,
				 parent, "testhook" );
    KAction *test2 = new KAction( i18n("Docbook Action2..."), 0,
				 parent, "docbook_test" );
}

//
// View Manager
//

DocBookViewManager::DocBookViewManager( DocType *type )
    : DocTypeViewManager( type ),
      editPart(0), htmlPart(0)
{

}

DocBookViewManager::~DocBookViewManager()
{
    if ( htmlPart || editPart ) {
	kdWarning() << "Deleting a DocBookViewManager while installed" << endl;
    }
}

void DocBookViewManager::openURL( const KURL &url )
{
    editPart->openURL( url );
    sourcePart()->openURL( url );
    KURL u2(url);
    u2.setProtocol( "help" );
    htmlPart->openURL( u2 );
}

void DocBookViewManager::installViews( QTabWidget *parent, KParts::PartManager *mng )
{
    // DocBook View
    KLibFactory *factory = KLibLoader::self()->factory( "libkhtml" );
    if ( !factory) {
	kdDebug() << "Failed to create factory for libkhtml" << endl;
    }

    htmlPart = static_cast<KHTMLPart *>( factory->create( parent, "html_viewer",
							  "KParts::ReadOnlyPart" ) );
    parent->insertTab( htmlPart->widget(), i18n("&Preview"), 0 );
    mng->addPart( htmlPart );

    // Editor page
    editPart = new RichTextEditPart( parent, "formatted_editor" );
    parent->insertTab( editPart->widget(), i18n("Forma&tted"), 0 );
    mng->addPart( editPart );

    installSourceView( parent, mng );
}

void DocBookViewManager::uninstallViews( QTabWidget *parent, KParts::PartManager *mng )
{
    if ( htmlPart ) {
	parent->removePage( htmlPart->widget() );
	mng->removePart( htmlPart );
	delete htmlPart;
	htmlPart = 0;
    }

    if ( editPart ) {
	parent->removePage( editPart->widget() );
	mng->removePart( editPart );
	delete editPart;
	editPart = 0;
    }

    uninstallSourceView( parent, mng );
}

KParts::Part *DocBookViewManager::findPart( QWidget *w )
{
    if ( (!editPart) || (!htmlPart) ) {
	kdDebug() << "DocBookViewManager: findPart() called before views were installed" << endl;
	return 0;
    }

    if ( w == editPart->widget() ) {
	return editPart;
    }
    else if ( w == htmlPart->widget() ) {
	return htmlPart;
    }

    return DocTypeViewManager::findPart( w );
}

// Local Variables:
// c-basic-offset: 4
// End:

