#include <qmultilineedit.h>
#include <qstylesheet.h>
#include <qtabwidget.h>

#include <kdebug.h>
#include <khtml_part.h>
#include <klibloader.h>
#include <klocale.h>

#include <rjmutils/richtexteditpart.h>
#include <rjmutils/srctexteditpart.h>

#include "htmldoctype.h"

HTMLDocType::HTMLDocType( const DocTypeInfo &info )
    : DocType( info )
{
}

QStyleSheet *HTMLDocType::styleSheet()
{
    return QStyleSheet::defaultSheet();
}

DocTypeViewManager *HTMLDocType::createViewManager()
{
    return new HTMLViewManager( this );
}

//
// View Manager
//

HTMLViewManager::HTMLViewManager( DocType *type )
    : DocTypeViewManager( type ),
      editPart(0), htmlPart(0)
{
}

HTMLViewManager::~HTMLViewManager()
{
    if ( htmlPart || editPart ) {
	kdWarning() << "Deleting a HTMLViewManager while installed" << endl;
    }
}

void HTMLViewManager::openURL( const KURL &url )
{
    editPart->openURL( url );
    htmlPart->openURL( url );
    sourcePart()->openURL( url );
}

void HTMLViewManager::installViews( QTabWidget *parent, KParts::PartManager *mng )
{
    // HTML View
    KLibFactory *factory = KLibLoader::self()->factory( "libkhtml" );
    if ( !factory) {
	kdDebug() << "Failed to create factory for libkhtml" << endl;
    }

    htmlPart = static_cast<KHTMLPart *>( factory->create( parent, "html_viewer",
							  "KParts::ReadOnlyPart" ) );
    parent->insertTab( htmlPart->widget(), i18n("&Preview"), 0 );
    mng->addPart( htmlPart );

    // Editor page
    editPart = new RichTextEditPart( parent, "formatted_editor" );
    parent->insertTab( editPart->widget(), i18n("Forma&tted"), 0 );
    mng->addPart( editPart );

    installSourceView( parent, mng );
}

void HTMLViewManager::uninstallViews( QTabWidget *parent, KParts::PartManager *mng )
{
    if ( htmlPart ) {
	parent->removePage( htmlPart->widget() );
	mng->removePart( htmlPart );
	delete htmlPart;
	htmlPart = 0;
    }

    if ( editPart ) {
	parent->removePage( editPart->widget() );
	mng->removePart( editPart );
	delete editPart;
	editPart = 0;
    }

    uninstallSourceView( parent, mng );
}

KParts::Part *HTMLViewManager::findPart( QWidget *w )
{
    if ( (!editPart) || (!htmlPart) ) {
	kdDebug() << "HTMLViewManager: findPart() called before views were installed" << endl;
	return 0;
    }

    if ( w == editPart->widget() ) {
	return editPart;
    }
    else if ( w == htmlPart->widget() ) {
	return htmlPart;
    }

    return DocTypeViewManager::findPart( w );
}

// Local Variables:
// c-basic-offset: 4
// End:

