#include <qmultilineedit.h>
#include <qstylesheet.h>
#include <qtabwidget.h>

#include <kdebug.h>
#include <klocale.h>

#include <rjmutils/richtexteditpart.h>
#include <rjmutils/srctexteditpart.h>

#include "qmldoctype.h"

QMLDocType::QMLDocType( const DocTypeInfo &info )
    : DocType( info )
{

}

QStyleSheet *QMLDocType::styleSheet()
{
    return QStyleSheet::defaultSheet();
}

DocTypeViewManager *QMLDocType::createViewManager()
{
    return new QMLViewManager( this );
}

//
// View Manager
//

QMLViewManager::QMLViewManager( DocType *type )
    : DocTypeViewManager( type ),
      editPart(0)
{
}

QMLViewManager::~QMLViewManager()
{
    if ( editPart ) {
	kdWarning() << "Deleting a QMLViewManager while installed" << endl;
    }
}

void QMLViewManager::openURL( const KURL &url )
{
    editPart->openURL( url );
    sourcePart()->openURL( url );
}

void QMLViewManager::installViews( QTabWidget *parent, KParts::PartManager *mng )
{
    // Editor page
    editPart = new RichTextEditPart( parent, "formatted_editor" );
    parent->insertTab( editPart->widget(), i18n("Forma&tted"), 0 );
    mng->addPart( editPart );

    installSourceView( parent, mng );
}

void QMLViewManager::uninstallViews( QTabWidget *parent, KParts::PartManager *mng )
{
    if ( editPart ) {
	parent->removePage( editPart->widget() );
	mng->removePart( editPart );
	delete editPart;
	editPart = 0;
    }

    uninstallSourceView( parent, mng );
}

KParts::Part *QMLViewManager::findPart( QWidget *w )
{
    if ( !editPart ) {
	kdDebug() << "QMLViewManager: findPart() called before views were installed" << endl;
	return 0;
    }

    if ( w == editPart->widget() ) {
	return editPart;
    }

    return DocTypeViewManager::findPart( w );
}

// Local Variables:
// c-basic-offset: 4
// End:


