#include <qstylesheet.h>
#include <qtabwidget.h>

#include <kaction.h>
#include <kconfig.h>
#include <kdebug.h>
#include <klocale.h>

#include <rjmutils/richtexteditpart.h>
#include <rjmutils/srctexteditpart.h>

#include "rdfstylesheet.h"

#include "rdfdoctype.h"

RDFDocType::RDFDocType( const DocTypeInfo &info )
    : DocType( info ),
      sheet(0)
{
    kdDebug() << "RDFDocType created" << endl;

    createActions( actionCollection() );
    setXMLFile( "doctypes/rdf/rdfui.rc" );
}

DocTypeViewManager *RDFDocType::createViewManager()
{
    kdDebug() << "RDFDocType creating view manager" << endl;
    return new RDFViewManager( this );
}

QStyleSheet *RDFDocType::styleSheet()
{
    if (!sheet) {
	kdDebug() << "RDFDocType: Creating a new stylesheet" << endl;
	sheet = new RDFStyleSheet();
    }
    return sheet;
}

void RDFDocType::createActions( KActionCollection *parent )
{
    KAction *test = new KAction( i18n("RDF Action..."), 0,
				 parent, "testhook" );
    KAction *test2 = new KAction( i18n("RDF Action2..."), 0,
				 parent, "rdf_test" );
}

//
// View Manager
//

RDFViewManager::RDFViewManager( DocType *type )
    : DocTypeViewManager( type ),
      editPart(0)
{
    kdDebug() << "RDFViewManager starting" << endl;
    KConfig *conf = type->config();
    if ( conf ) {
	kdDebug() << "RDFViewManager got config object" << endl;
    }

}

RDFViewManager::~RDFViewManager()
{
    if ( editPart ) {
	kdWarning() << "Deleting a RDFViewManager while installed" << endl;
    }
}

void RDFViewManager::openURL( const KURL &url )
{
    kdDebug() << "RDFViewManager: openURL" << endl;
    editPart->widget()->setTextFormat( Qt::RichText );
    editPart->widget()->setStyleSheet( docType()->styleSheet() );
    editPart->openURL( url );
    sourcePart()->openURL( url );
}

void RDFViewManager::installViews( QTabWidget *parent, KParts::PartManager *mng )
{
    // Editor page
    editPart = new RichTextEditPart( parent, "formatted_editor" );
    parent->insertTab( editPart->widget(), i18n("Forma&tted"), 0 );
    mng->addPart( editPart );

    installSourceView( parent, mng );
}

void RDFViewManager::uninstallViews( QTabWidget *parent, KParts::PartManager *mng )
{
    if ( editPart ) {
	parent->removePage( editPart->widget() );
	mng->removePart( editPart );
	delete editPart;
	editPart = 0;
    }

    uninstallSourceView( parent, mng );
}

KParts::Part *RDFViewManager::findPart( QWidget *w )
{
    if ( !editPart ) {
	kdDebug() << "RDFViewManager: findPart() called before views were installed" << endl;
	return 0;
    }

    if ( w == editPart->widget() ) {
	return editPart;
    }

    return DocTypeViewManager::findPart( w );
}


// Local Variables:
// c-basic-offset: 4
// End:

