#include <qtabwidget.h>

#include <kdebug.h>
#include <klibloader.h>
#include <klocale.h>

#include "doctypeviewmanager.h"

#define USE_KATE_PART


DocTypeViewManager::DocTypeViewManager( DocType *dt )
    : type(dt), srcPart(0)
{

}

void DocTypeViewManager::installSourceView( QTabWidget *parent, KParts::PartManager *mng )
{
#ifdef USE_KATE_PART
    KLibFactory *factory = KLibLoader::self()->factory( "libkatepart" );
    if ( !factory) {
	kdDebug() << "Failed to create factory for libkatepart" << endl;
    }

    srcPart = static_cast<KParts::ReadWritePart *>( factory->create( parent, "source_editor",
								     "KParts::ReadWritePart" ) );

    if ( !srcPart) {
	kdDebug() << "Failed to create kate editor part" << endl;
    }
#endif

    if ( !srcPart )
	srcPart = new SrcTextEditPart( parent, "source_editor" );

    parent->insertTab( srcPart->widget(), i18n("&Source"), 0 );
    mng->addPart( srcPart );
}

void DocTypeViewManager::uninstallSourceView( QTabWidget *parent, KParts::PartManager *mng )
{
    if ( srcPart ) {
	parent->removePage( srcPart->widget() );
	mng->removePart( srcPart );
	delete srcPart;
	srcPart = 0;
    }
}

KParts::Part *DocTypeViewManager::findPart( QWidget *w )
{
    if ( srcPart && ( w == srcPart->widget() ) )
	return srcPart;
    else
	return 0;
}

// Local Variables:
// c-basic-offset: 4
// End:

