#include <assert.h>

#include <qfile.h>
#include <qtextview.h>

#include <kaction.h>
#include <kapplication.h>
#include <kdebug.h>
#include <kfiledialog.h>
#include <klistview.h>
#include <klocale.h>
#include <kstatusbar.h>
#include <kstdaction.h>

#include <kjs/interpreter.h>
#include "kjsembed/jsobjectproxy.h"
#include "kjsembed/jsconsolepart.h"
#include "kjsembed/messagelogwidget.h"

#include <rjmutils/domtreepart.h>

#include "global.h"
#include "document.h"
#include "doctype.h"
#include "doctypemanager.h"
#include "doctypeviewmanager.h"
#include "document.h"

#include "xmelegance.h"
#include "xmelegance.moc"

XMElegance::XMElegance()
    : TriMainWindow( 0, "XMElegance" ),
      recent_files(0), show_sidebar(0), show_messages(0),
      partManager(0), docViewMng(0), doc(0),
      domTree(0), msgView(0), jsConsole(0)
{
    // Setup managers
    partManager = new KParts::PartManager( this );
    partManager->setAllowNestedParts( true );
    doc = new Document( this );

    // Setup Views
    setupSidebar();
    setupDocViews();
    setupMessageViews();
    setupBindings();

    // Setup main window
    statusBar()->message( "XMElegance", 2000 );
    setupActions();

    // Activate KParts
    createGUI( 0 );
    connect( partManager, SIGNAL( activePartChanged( KParts::Part * ) ),
	     this, SLOT( createGUI( KParts::Part * ) ) );
}

XMElegance::~XMElegance()
{
}

void XMElegance::activeViewChanged( QWidget *w )
{
    KParts::Part *p = (docViewMng ? docViewMng->findPart( w ) : 0);
    if ( p ) {
	partManager->setActivePart( p );

	return;
    }

    if ( w == jsConsole->widget() ) {
	partManager->setActivePart( jsConsole );
	return;
    }

    if ( w == domTree->widget() ) {
	partManager->setActivePart( domTree );
	return;
    }

    partManager->setActivePart( 0 );
}

void XMElegance::setupActions()
{
  new KAction( i18n("RDF Action2..."), 0, actionCollection(), "testhook2" );


    // Actions
    KStdAction::open( this, SLOT( open() ), actionCollection() );
    KStdAction::quit( this, SLOT( close() ), actionCollection() );

    recent_files = KStdAction::openRecent( this, SLOT( openURL(const KURL &) ),
					   actionCollection() );
    recent_files->loadEntries( kapp->config() );

    //XXX: Remove manual icon loading
    QPixmap sbpm( "tree_win.png" );
    show_sidebar = new KToggleAction( i18n( "Show &Sidebar" ), QIconSet(sbpm), CTRL+Key_T,
				      0, 0,
				      actionCollection(), "show_hide_sidebar" );
    show_sidebar->setChecked( true );
    show_sidebar->setStatusText( i18n("Shows or hides the sidebar") );
    connect( show_sidebar, SIGNAL( toggled(bool) ),
	     this, SLOT( setSidebarVisible(bool) ) );

    QPixmap smpm( "output_win.png" );
    show_messages = new KToggleAction( i18n( "Show &Messages" ), QIconSet(smpm), CTRL+Key_M,
				       0, 0,
				       actionCollection(), "show_hide_messages" );
    show_messages->setChecked( true );
    show_messages->setStatusText( i18n("Shows or hides the message pane") );
    connect( show_messages, SIGNAL( toggled(bool) ),
	     this, SLOT( setMessagesVisible(bool) ) );

    actionCollection()->setHighlightingEnabled( true );
    connect( actionCollection(), SIGNAL( actionStatusText(const QString &) ),
	     statusBar(), SLOT( message(const QString &) ) );
    connect( actionCollection(), SIGNAL( clearStatusText() ),
	     statusBar(), SLOT( clear() ) );
}

void XMElegance::open()
{
    KURL url = KFileDialog::getOpenURL( ":document" );
    if ( !url.isEmpty() )
	openURL( url );
}

//
// Sidebar Views
//

void XMElegance::setupSidebar()
{
    QTabWidget *sidebar = sideWidget();
    // Sidebar container
    connect( sidebar, SIGNAL( currentChanged( QWidget * ) ),
	     this, SLOT( activeViewChanged( QWidget * ) ) );

    // Sidebars
    domTree = new DOMTreePart( sidebar, "dom_tree" );
    sidebar->addTab( domTree->widget(), "&Doc Tree" );
    partManager->addPart( domTree );

    QTextView *test = new QTextView( sidebar, "test_view" );
    test->setText( "This is some text...\n"
		   "This is some text...\n"
		   "This is some text...\n"
		   "This is some text...\n"
		   "This is some text...\n"
		   "This is some text...\n" );
    sidebar->addTab( test, "Test" );
}

//
// Document Views
//

void XMElegance::setupDocViews()
{
    // View container
    connect( docWidget(), SIGNAL( currentChanged( QWidget * ) ),
	     this, SLOT( activeViewChanged( QWidget * ) ) );
}

void XMElegance::openURL( const KURL &url )
{
    if ( doc )
	delete doc;
    Document *newdoc = new Document( this );
    doc = newdoc;
    newdoc->openURL( url );
    installDocType( newdoc->docType() );

    docViewMng->openURL( url );
    domTree->openURL( url );

    recent_files->addURL( url );
    recent_files->saveEntries( kapp->config() );

}

void XMElegance::installDocType( DocType *docType )
{
    assert( docType );

    kdDebug() << "installDocType()" << endl;

    if (msgView->run( "echo Hello World!" ) )
	kdDebug() << "echo test returned true" << endl;
    else
	kdDebug() << "echo test returned false" << endl;

    if ( docViewMng ) {
	// Uninstall XMLGUI Client for the old doctype
	factory()->removeClient( doc->docType() );
	docViewMng->uninstallViews( docWidget(), partManager );
	delete docViewMng;
        createGUI( 0 );
    }


    docViewMng = docType->createViewManager();
    kdDebug() << "docViewMng created view manager" << endl;

    QTabWidget *docViews = docWidget();
    docViewMng->installViews( docViews, partManager );
    docViews->updateGeometry();

    // Install XMLGUI Client for doctype
    factory()->addClient( docType );
    activeViewChanged( docViews->currentPage() );

    QString msg( "%1 (%2)" );
    statusBar()->message( msg.arg( docType->info().description() ).arg( docType->info().mimeType() ) );
}

//
// Message Views
//

void XMElegance::setupMessageViews()
{
    QTabWidget *messages = messageWidget();

    // Message view container
    connect( messages, SIGNAL( currentChanged( QWidget * ) ),
	     this, SLOT( activeViewChanged( QWidget * ) ) );

    // Messages view
    msgView = new KJSEmbed::MessageLogWidget( messages );
    msgView->message( i18n("<b>XMElegance started</b><br>") );
    messages->addTab( msgView, "&Messages" );

    // JSConsole view
    jsConsole = new KJSEmbed::JSConsolePart( Global::jscript(), messages );
    messages->addTab( jsConsole->widget(), "&JScript" );
    partManager->addPart( jsConsole );


}

void XMElegance::setupBindings()
{
    KJS::Interpreter *js = Global::jscript();

    // Self
    KJSEmbed::JSObjectProxy *proxy = new KJSEmbed::JSObjectProxy( js, this );
    KJS::Object jsSelf( proxy );
    proxy->addBindings( js->globalExec(), jsSelf );
    js->globalObject().put( js->globalExec(), "xmel", KJS::Object( proxy ) );

    // JS Console
    KJSEmbed::JSConsoleWidget *console = jsConsole->widget();
    KJS::Object global = js->globalObject();
    console->addBindings( js->globalExec(), global );
}

// Local Variables:
// c-basic-offset: 4
// End:

